@@ -1,15 +1,14 @@
 from typing import IO
 
-import yaml
-
 from commanderbot_lib.database.abc.file_database import FileDatabase
+from commanderbot_lib.database.mixins.yaml_file_database_mixin import YamlFileDatabaseMixin
 
 
-class YamlFileDatabase(FileDatabase):
+class YamlFileDatabase(FileDatabase, YamlFileDatabaseMixin):
     # @implements FileDatabase
     async def load(self, file: IO) -> dict:
-        return yaml.safe_load(file)
+        return await self.load_yaml(file)
 
     # @implements FileDatabase
     async def dump(self, data: dict, file: IO):
-        return yaml.safe_dump(data, file)
+        await self.dump_yaml(data, file)
